<?php
/**
* The header for CleanWP theme.
*
* @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
*
* @package CleanWP WordPress Theme
* @copyright Copyright (C) 2018 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
<?php wp_head(); ?>
</head>

<body <?php body_class(); ?> itemscope="itemscope" itemtype="http://schema.org/WebPage">
<?php wp_body_open(); ?>
<div id="wrapper">
<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'cleanwp' ); ?></a>

<?php cleanwp_before_header(); ?>

<header id="masthead" class="site-header" itemscope="itemscope" itemtype="http://schema.org/WPHeader" role="banner">

<div id="site-top">
<div id="blogname">
<?php if ( get_header_image() ) : ?>
    <div class="site-branding">
    <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" style="display: block;">
        <img src="<?php header_image(); ?>" width="<?php echo esc_attr(get_custom_header()->width); ?>" height="<?php echo esc_attr(get_custom_header()->height); ?>" alt="" class="header-image"/>
    </a>
    </div>
<?php else: ?>
    <?php if ( has_custom_logo() ) : ?>
        <div class="site-branding" style="text-align:center;">
        <a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home" style="display: block;">
            <img src="<?php echo esc_url( cleanwp_custom_logo() ); ?>" alt="" class="header-image"/>
        </a>
        </div>
    <?php else: ?>
        <div class="site-branding">
          <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
          <h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
        </div>
    <?php endif; ?>
<?php endif; // End header image check. ?>
</div>

<div class="header-social-icons">
    <?php if ( !(cleanwp_get_option('hide_social_buttons')) ) { ?>
    <?php if ( cleanwp_get_option('facebooklink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('facebooklink') ); ?>" target="_blank" class="social-facebook" title="Facebook"><i class="fa fa-facebook" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('twitterlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('twitterlink') ); ?>" target="_blank" class="social-twitter" title="Twitter"><i class="fa fa-twitter" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('googlelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('googlelink') ); ?>" target="_blank" class="social-googleplus" title="Google Plus"><i class="fa fa-google-plus" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('pinterestlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('pinterestlink') ); ?>" target="_blank" class="social-pinterest" title="Pinterest"><i class="fa fa-pinterest" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('linkedinlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('linkedinlink') ); ?>" target="_blank" class="social-linkedin" title="Linkedin"><i class="fa fa-linkedin" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('instagramlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('instagramlink') ); ?>" target="_blank" class="social-instagram" title="Instagram"><i class="fa fa-instagram" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('flickrlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('flickrlink') ); ?>" target="_blank" class="social-flickr" title="Flickr"><i class="fa fa-flickr" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('youtubelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('youtubelink') ); ?>" target="_blank" class="social-youtube" title="Youtube"><i class="fa fa-youtube" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('vimeolink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('vimeolink') ); ?>" target="_blank" class="social-vimeo" title="Vimeo"><i class="fa fa-vimeo" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('soundcloudlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('soundcloudlink') ); ?>" target="_blank" class="social-soundcloud" title="SoundCloud"><i class="fa fa-soundcloud" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('lastfmlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('lastfmlink') ); ?>" target="_blank" class="social-lastfm" title="Lastfm"><i class="fa fa-lastfm" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('githublink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('githublink') ); ?>" target="_blank" class="social-github" title="Github"><i class="fa fa-github" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('bitbucketlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('bitbucketlink') ); ?>" target="_blank" class="social-bitbucket" title="Bitbucket"><i class="fa fa-bitbucket" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('tumblrlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('tumblrlink') ); ?>" target="_blank" class="social-tumblr" title="Tumblr"><i class="fa fa-tumblr" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('digglink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('digglink') ); ?>" target="_blank" class="social-digg" title="Digg"><i class="fa fa-digg" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('deliciouslink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('deliciouslink') ); ?>" target="_blank" class="social-delicious" title="Delicious"><i class="fa fa-delicious" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('stumblelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('stumblelink') ); ?>" target="_blank" class="social-stumbleupon" title="Stumbleupon"><i class="fa fa-stumbleupon" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('redditlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('redditlink') ); ?>" target="_blank" class="social-reddit" title="Reddit"><i class="fa fa-reddit" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('dribbblelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('dribbblelink') ); ?>" target="_blank" class="social-dribbble" title="Dribbble"><i class="fa fa-dribbble" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('behancelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('behancelink') ); ?>" target="_blank" class="social-behance" title="Behance"><i class="fa fa-behance" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('codepenlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('codepenlink') ); ?>" target="_blank" class="social-codepen" title="Codepen"><i class="fa fa-codepen" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('jsfiddlelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('jsfiddlelink') ); ?>" target="_blank" class="social-jsfiddle" title="JSFiddle"><i class="fa fa-jsfiddle" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('stackoverflowlink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('stackoverflowlink') ); ?>" target="_blank" class="social-stackoverflow" title="Stack Overflow"><i class="fa fa-stack-overflow" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('stackexchangelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('stackexchangelink') ); ?>" target="_blank" class="social-stackexchange" title="Stack Exchange"><i class="fa fa-stack-exchange" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('bsalink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('bsalink') ); ?>" target="_blank" class="social-buysellads" title="BuySellAds"><i class="fa fa-buysellads" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('slidesharelink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('slidesharelink') ); ?>" target="_blank" class="social-slideshare" title="SlideShare"><i class="fa fa-slideshare" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('skypeusername') ) : ?>
            <a href="skype:<?php echo esc_html( cleanwp_get_option('skypeusername') ); ?>?chat" class="social-skype" title="Skype"><i class="fa fa-skype" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('emailaddress') ) : ?>
            <a href="mailto:<?php echo esc_html( cleanwp_get_option('emailaddress') ); ?>" class="social-email" title="Email Us"><i class="fa fa-envelope" aria-hidden="true"></i></a><?php endif; ?>
    <?php if ( cleanwp_get_option('rsslink') ) : ?>
            <a href="<?php echo esc_url( cleanwp_get_option('rsslink') ); ?>" target="_blank" class="social-rss" title="RSS"><i class="fa fa-rss" aria-hidden="true"></i></a><?php endif; ?>
        <?php } ?>
</div>
</div>
    
<nav id="site-navigation" class="main-navigation clearfix" itemscope="itemscope" itemtype="http://schema.org/SiteNavigationElement" role="navigation">
    <button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false"><?php esc_html_e( 'Menu', 'cleanwp' ); ?></button>
    <?php wp_nav_menu( array( 'theme_location' => 'primary', 'menu_id' => 'primary-menu' ) ); ?>
</nav><!-- #site-navigation -->

<?php cleanwp_after_primary_menu(); ?>

</header><!--end masthead-->

<?php cleanwp_after_header(); ?>

<div id="content" class="site-content">